Computes the first-exposure effect (FEE) for a model estimated using the
one-inflated positive Poisson distribution. The FEE represents the change in
expected counts associated with the first exposure to treatment, relative to
the counterfactual positive Poisson model.This function is used internally by
fee at given covariate values.
fee_pois(b, g, X, Z)A numeric vector of first-exposure effect(s).
A numeric vector of estimated coefficients for the rate.
A numeric vector of estimated coefficients for inflation.
A numeric matrix of covariates for the rate.
A numeric matrix of covariates for inflation.
fee, fee_negbin